==> pgbackrest_2.44.orig.tar.gz: pgbackrest-release-2.44/src/common/compress/zst/compress.h <==
/***********************************************************************************************************************************
ZST Compress

Compress IO to the zst format.
***********************************************************************************************************************************/
#ifdef HAVE_LIBZST

#ifndef COMMON_COMPRESS_ZST_COMPRESS_H
#define COMMON_COMPRESS_ZST_COMPRESS_H

#include "common/io/filter/filter.h"

/***********************************************************************************************************************************
Filter type constant
***********************************************************************************************************************************/
#define ZST_COMPRESS_FILTER_TYPE                                    STRID5("zst-cmp", 0x41a3dd27a0)

/***********************************************************************************************************************************
Level constants
***********************************************************************************************************************************/
#define ZST_COMPRESS_LEVEL_DEFAULT                                  3
#define ZST_COMPRESS_LEVEL_MIN                                      -7
#define ZST_COMPRESS_LEVEL_MAX                                      22

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
FN_EXTERN IoFilter *zstCompressNew(int level);

#endif

#endif // HAVE_LIBZST

==> pgbackrest_2.55.1.orig.tar.gz: pgbackrest-release-2.55.1/src/common/compress/zst/compress.h <==
/***********************************************************************************************************************************
ZST Compress

Compress IO to the zst format.
***********************************************************************************************************************************/
#ifdef HAVE_LIBZST

#ifndef COMMON_COMPRESS_ZST_COMPRESS_H
#define COMMON_COMPRESS_ZST_COMPRESS_H

#include "common/io/filter/filter.h"

/***********************************************************************************************************************************
Filter type constant
***********************************************************************************************************************************/
#define ZST_COMPRESS_FILTER_TYPE                                    STRID5("zst-cmp", 0x41a3dd27a0)

/***********************************************************************************************************************************
Level constants
***********************************************************************************************************************************/
#define ZST_COMPRESS_LEVEL_DEFAULT                                  3
#define ZST_COMPRESS_LEVEL_MIN                                      -7
#define ZST_COMPRESS_LEVEL_MAX                                      22

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
FN_EXTERN IoFilter *zstCompressNew(int level, bool raw);

#endif

#endif // HAVE_LIBZST
